@@ -189,7 +189,7 @@ ERROR
 sub compile {
     my $self = shift;
 
-    return join "\n", '{',
+    my $code = join "\n", '{',
                       $self->_compile_package,
                       $self->_compile_pragmas,
                       $self->_compile_extends,
@@ -197,6 +197,8 @@ sub compile {
                       $self->_compile_attribute_accessors,
                       '1;',
                       '}';
+    #::diag $code;
+    return $code;
 }
 
 sub _compile_package {
@@ -250,7 +252,7 @@ sub _compile_bless {
 sub _compile_strict_constructor {
     my $self = shift;
 
-    return 'keys %$args and do { require Carp; Carp::croak("Unexpected keys in contructor: " . join(q[, ], sort keys %$args)) };';
+    return 'keys %$args and do { require Carp; Carp::croak("Unexpected keys in constructor: " . join(q[, ], sort keys %$args)) };';
 }
 
 sub _compile_new {
